@@ -76,16 +76,7 @@ class DevContainer(
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                project: _Project_57d89203,
-                *,
-                docker_image: typing.Optional[_DevEnvironmentDockerImage_4a8d8ffd] = None,
-                ports: typing.Optional[typing.Sequence[builtins.str]] = None,
-                tasks: typing.Optional[typing.Sequence[_Task_9fa875b6]] = None,
-                vscode_extensions: typing.Optional[typing.Sequence[builtins.str]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__50747b0b39db339de569d0b44aea84c4de3c0d9d7b268479f1a3852dfb712c0b)
             check_type(argname="argument project", value=project, expected_type=type_hints["project"])
         options = DevContainerOptions(
             docker_image=docker_image,
@@ -105,9 +96,7 @@ class DevContainer(
         :stability: experimental
         '''
         if __debug__:
-            def stub(image: _DevEnvironmentDockerImage_4a8d8ffd) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__24cf7d35da522ed5017c6db46a2565a5b5a09fbffc1dafabdf917aa798fea91d)
             check_type(argname="argument image", value=image, expected_type=type_hints["image"])
         return typing.cast(None, jsii.invoke(self, "addDockerImage", [image]))
 
@@ -120,9 +109,7 @@ class DevContainer(
         :stability: experimental
         '''
         if __debug__:
-            def stub(*ports: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__3898b547dc05a8cd9427e24743e3ec87b3108cfb90befb94e77c24e156c3559d)
             check_type(argname="argument ports", value=ports, expected_type=typing.Tuple[type_hints["ports"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "addPorts", [*ports]))
 
@@ -137,9 +124,7 @@ class DevContainer(
         :stability: experimental
         '''
         if __debug__:
-            def stub(*tasks: _Task_9fa875b6) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__4eccb3fb9f6eca40de5ffa59e4b75a85830e1113729bd9b08dc7e4128c2bfde0)
             check_type(argname="argument tasks", value=tasks, expected_type=typing.Tuple[type_hints["tasks"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "addTasks", [*tasks]))
 
@@ -152,9 +137,7 @@ class DevContainer(
         :stability: experimental
         '''
         if __debug__:
-            def stub(*extensions: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__c13b0cafe05fa1eb28182ec3465e43421a4aa7c7e44e035db34dd4cdbce24537)
             check_type(argname="argument extensions", value=extensions, expected_type=typing.Tuple[type_hints["extensions"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "addVscodeExtensions", [*extensions]))
 
@@ -200,20 +183,12 @@ class DevContainerOptions(_DevEnvironmentOptions_b10d89d1):
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                *,
-                docker_image: typing.Optional[_DevEnvironmentDockerImage_4a8d8ffd] = None,
-                ports: typing.Optional[typing.Sequence[builtins.str]] = None,
-                tasks: typing.Optional[typing.Sequence[_Task_9fa875b6]] = None,
-                vscode_extensions: typing.Optional[typing.Sequence[builtins.str]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__b22d9ca6de29afcacfab2404c9835e6e3021ec640c49dfdad9bfb651e564c725)
             check_type(argname="argument docker_image", value=docker_image, expected_type=type_hints["docker_image"])
             check_type(argname="argument ports", value=ports, expected_type=type_hints["ports"])
             check_type(argname="argument tasks", value=tasks, expected_type=type_hints["tasks"])
             check_type(argname="argument vscode_extensions", value=vscode_extensions, expected_type=type_hints["vscode_extensions"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if docker_image is not None:
             self._values["docker_image"] = docker_image
         if ports is not None:
@@ -314,18 +289,11 @@ class Presentation:
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                *,
-                group: builtins.str,
-                hidden: builtins.bool,
-                order: jsii.Number,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__924d6d8e838c592ce2bb743a8e91cb4b0f379f000355379bd65232dabc6f4efe)
             check_type(argname="argument group", value=group, expected_type=type_hints["group"])
             check_type(argname="argument hidden", value=hidden, expected_type=type_hints["hidden"])
             check_type(argname="argument order", value=order, expected_type=type_hints["order"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "group": group,
             "hidden": hidden,
             "order": order,
@@ -392,18 +360,11 @@ class ServerReadyAction:
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                *,
-                action: builtins.str,
-                pattern: typing.Optional[builtins.str] = None,
-                uri_format: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__66fa6feb4bea9673155e5f489baae5bbdd6d528f7ce29ff754c6915092eb7036)
             check_type(argname="argument action", value=action, expected_type=type_hints["action"])
             check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
             check_type(argname="argument uri_format", value=uri_format, expected_type=type_hints["uri_format"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "action": action,
         }
         if pattern is not None:
@@ -464,9 +425,7 @@ class VsCode(
         :stability: experimental
         '''
         if __debug__:
-            def stub(project: _Project_57d89203) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__f494cab4044809f412c6dee4a08eb9aa6d128399b6c0dfdbe5d9be6e2622fed5)
             check_type(argname="argument project", value=project, expected_type=type_hints["project"])
         jsii.create(self.__class__, self, [project])
 
@@ -512,9 +471,7 @@ class VsCodeLaunchConfig(
         :stability: experimental
         '''
         if __debug__:
-            def stub(vscode: VsCode) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__fbb203f423ffcc3e6227caf2f8624610dfdc5c528c756efd2e3094d0db32f059)
             check_type(argname="argument vscode", value=vscode, expected_type=type_hints["vscode"])
         jsii.create(self.__class__, self, [vscode])
 
@@ -537,10 +494,10 @@ class VsCodeLaunchConfig(
         port: typing.Optional[jsii.Number] = None,
         post_debug_task: typing.Optional[builtins.str] = None,
         pre_launch_task: typing.Optional[builtins.str] = None,
-        presentation: typing.Optional[typing.Union[Presentation, typing.Dict[str, typing.Any]]] = None,
+        presentation: typing.Optional[typing.Union[Presentation, typing.Dict[builtins.str, typing.Any]]] = None,
         program: typing.Optional[builtins.str] = None,
         runtime_args: typing.Optional[typing.Sequence[builtins.str]] = None,
-        server_ready_action: typing.Optional[typing.Union[ServerReadyAction, typing.Dict[str, typing.Any]]] = None,
+        server_ready_action: typing.Optional[typing.Union[ServerReadyAction, typing.Dict[builtins.str, typing.Any]]] = None,
         skip_files: typing.Optional[typing.Sequence[builtins.str]] = None,
         stop_on_entry: typing.Optional[builtins.bool] = None,
         url: typing.Optional[builtins.str] = None,
@@ -651,10 +608,10 @@ class VsCodeLaunchConfigurationEntry:
         port: typing.Optional[jsii.Number] = None,
         post_debug_task: typing.Optional[builtins.str] = None,
         pre_launch_task: typing.Optional[builtins.str] = None,
-        presentation: typing.Optional[typing.Union[Presentation, typing.Dict[str, typing.Any]]] = None,
+        presentation: typing.Optional[typing.Union[Presentation, typing.Dict[builtins.str, typing.Any]]] = None,
         program: typing.Optional[builtins.str] = None,
         runtime_args: typing.Optional[typing.Sequence[builtins.str]] = None,
-        server_ready_action: typing.Optional[typing.Union[ServerReadyAction, typing.Dict[str, typing.Any]]] = None,
+        server_ready_action: typing.Optional[typing.Union[ServerReadyAction, typing.Dict[builtins.str, typing.Any]]] = None,
         skip_files: typing.Optional[typing.Sequence[builtins.str]] = None,
         stop_on_entry: typing.Optional[builtins.bool] = None,
         url: typing.Optional[builtins.str] = None,
@@ -693,34 +650,7 @@ class VsCodeLaunchConfigurationEntry:
         if isinstance(server_ready_action, dict):
             server_ready_action = ServerReadyAction(**server_ready_action)
         if __debug__:
-            def stub(
-                *,
-                name: builtins.str,
-                request: builtins.str,
-                type: builtins.str,
-                args: typing.Optional[typing.Sequence[builtins.str]] = None,
-                console: typing.Optional[Console] = None,
-                cwd: typing.Optional[builtins.str] = None,
-                debug_server: typing.Optional[jsii.Number] = None,
-                disable_optimistic_b_ps: typing.Optional[builtins.bool] = None,
-                env: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.str, builtins.bool]]] = None,
-                env_file: typing.Optional[builtins.str] = None,
-                internal_console_options: typing.Optional[InternalConsoleOptions] = None,
-                out_files: typing.Optional[typing.Sequence[builtins.str]] = None,
-                port: typing.Optional[jsii.Number] = None,
-                post_debug_task: typing.Optional[builtins.str] = None,
-                pre_launch_task: typing.Optional[builtins.str] = None,
-                presentation: typing.Optional[typing.Union[Presentation, typing.Dict[str, typing.Any]]] = None,
-                program: typing.Optional[builtins.str] = None,
-                runtime_args: typing.Optional[typing.Sequence[builtins.str]] = None,
-                server_ready_action: typing.Optional[typing.Union[ServerReadyAction, typing.Dict[str, typing.Any]]] = None,
-                skip_files: typing.Optional[typing.Sequence[builtins.str]] = None,
-                stop_on_entry: typing.Optional[builtins.bool] = None,
-                url: typing.Optional[builtins.str] = None,
-                web_root: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__76028c8d6272b5133841fb2049bcddc9a00879405477a0aa27f058f8ac6dc481)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument request", value=request, expected_type=type_hints["request"])
             check_type(argname="argument type", value=type, expected_type=type_hints["type"])
@@ -744,7 +674,7 @@ class VsCodeLaunchConfigurationEntry:
             check_type(argname="argument stop_on_entry", value=stop_on_entry, expected_type=type_hints["stop_on_entry"])
             check_type(argname="argument url", value=url, expected_type=type_hints["url"])
             check_type(argname="argument web_root", value=web_root, expected_type=type_hints["web_root"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "name": name,
             "request": request,
             "type": type,
@@ -1009,9 +939,7 @@ class VsCodeRecommendedExtensions(
         :stability: experimental
         '''
         if __debug__:
-            def stub(vscode: VsCode) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__e672107e647965d3df7010fe525812b0c15f85ddada55b01f48ebe2c3d565725)
             check_type(argname="argument vscode", value=vscode, expected_type=type_hints["vscode"])
         jsii.create(self.__class__, self, [vscode])
 
@@ -1024,9 +952,7 @@ class VsCodeRecommendedExtensions(
         :stability: experimental
         '''
         if __debug__:
-            def stub(*extensions: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__ee54c74ab4b20a8248223537312409aad3f546c2c5aeca6044e4346ce5a952d8)
             check_type(argname="argument extensions", value=extensions, expected_type=typing.Tuple[type_hints["extensions"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "addRecommendations", [*extensions]))
 
@@ -1041,9 +967,7 @@ class VsCodeRecommendedExtensions(
         :stability: experimental
         '''
         if __debug__:
-            def stub(*extensions: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__d1a69619f76a087ea88b4c83f8cee17e5d30db36f27b14f84da086de6e449d0c)
             check_type(argname="argument extensions", value=extensions, expected_type=typing.Tuple[type_hints["extensions"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "addUnwantedRecommendations", [*extensions]))
 
@@ -1065,9 +989,7 @@ class VsCodeSettings(
         :stability: experimental
         '''
         if __debug__:
-            def stub(vscode: VsCode) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__513f68cf91869cc8da990fa2a1bc57a9c643d25b8264e1c057f76e3decc6dea1)
             check_type(argname="argument vscode", value=vscode, expected_type=type_hints["vscode"])
         jsii.create(self.__class__, self, [vscode])
 
@@ -1087,13 +1009,7 @@ class VsCodeSettings(
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                setting: builtins.str,
-                value: typing.Any,
-                language: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__369e06bc45a74498b4cfed5bf740550cd9a57917b148178ef260593cb40c2a59)
             check_type(argname="argument setting", value=setting, expected_type=type_hints["setting"])
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
             check_type(argname="argument language", value=language, expected_type=type_hints["language"])
@@ -1113,12 +1029,7 @@ class VsCodeSettings(
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                settings: typing.Mapping[builtins.str, typing.Any],
-                languages: typing.Optional[typing.Union[builtins.str, typing.Sequence[builtins.str]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__fa3e27ee6b180fccd6eab5d9670c7024eb3f8067cb08859636119e69f07de239)
             check_type(argname="argument settings", value=settings, expected_type=type_hints["settings"])
             check_type(argname="argument languages", value=languages, expected_type=type_hints["languages"])
         return typing.cast(None, jsii.invoke(self, "addSettings", [settings, languages]))
@@ -1139,3 +1050,146 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__50747b0b39db339de569d0b44aea84c4de3c0d9d7b268479f1a3852dfb712c0b(
+    project: _Project_57d89203,
+    *,
+    docker_image: typing.Optional[_DevEnvironmentDockerImage_4a8d8ffd] = None,
+    ports: typing.Optional[typing.Sequence[builtins.str]] = None,
+    tasks: typing.Optional[typing.Sequence[_Task_9fa875b6]] = None,
+    vscode_extensions: typing.Optional[typing.Sequence[builtins.str]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__24cf7d35da522ed5017c6db46a2565a5b5a09fbffc1dafabdf917aa798fea91d(
+    image: _DevEnvironmentDockerImage_4a8d8ffd,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3898b547dc05a8cd9427e24743e3ec87b3108cfb90befb94e77c24e156c3559d(
+    *ports: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4eccb3fb9f6eca40de5ffa59e4b75a85830e1113729bd9b08dc7e4128c2bfde0(
+    *tasks: _Task_9fa875b6,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c13b0cafe05fa1eb28182ec3465e43421a4aa7c7e44e035db34dd4cdbce24537(
+    *extensions: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b22d9ca6de29afcacfab2404c9835e6e3021ec640c49dfdad9bfb651e564c725(
+    *,
+    docker_image: typing.Optional[_DevEnvironmentDockerImage_4a8d8ffd] = None,
+    ports: typing.Optional[typing.Sequence[builtins.str]] = None,
+    tasks: typing.Optional[typing.Sequence[_Task_9fa875b6]] = None,
+    vscode_extensions: typing.Optional[typing.Sequence[builtins.str]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__924d6d8e838c592ce2bb743a8e91cb4b0f379f000355379bd65232dabc6f4efe(
+    *,
+    group: builtins.str,
+    hidden: builtins.bool,
+    order: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__66fa6feb4bea9673155e5f489baae5bbdd6d528f7ce29ff754c6915092eb7036(
+    *,
+    action: builtins.str,
+    pattern: typing.Optional[builtins.str] = None,
+    uri_format: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f494cab4044809f412c6dee4a08eb9aa6d128399b6c0dfdbe5d9be6e2622fed5(
+    project: _Project_57d89203,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__fbb203f423ffcc3e6227caf2f8624610dfdc5c528c756efd2e3094d0db32f059(
+    vscode: VsCode,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__76028c8d6272b5133841fb2049bcddc9a00879405477a0aa27f058f8ac6dc481(
+    *,
+    name: builtins.str,
+    request: builtins.str,
+    type: builtins.str,
+    args: typing.Optional[typing.Sequence[builtins.str]] = None,
+    console: typing.Optional[Console] = None,
+    cwd: typing.Optional[builtins.str] = None,
+    debug_server: typing.Optional[jsii.Number] = None,
+    disable_optimistic_b_ps: typing.Optional[builtins.bool] = None,
+    env: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.str, builtins.bool]]] = None,
+    env_file: typing.Optional[builtins.str] = None,
+    internal_console_options: typing.Optional[InternalConsoleOptions] = None,
+    out_files: typing.Optional[typing.Sequence[builtins.str]] = None,
+    port: typing.Optional[jsii.Number] = None,
+    post_debug_task: typing.Optional[builtins.str] = None,
+    pre_launch_task: typing.Optional[builtins.str] = None,
+    presentation: typing.Optional[typing.Union[Presentation, typing.Dict[builtins.str, typing.Any]]] = None,
+    program: typing.Optional[builtins.str] = None,
+    runtime_args: typing.Optional[typing.Sequence[builtins.str]] = None,
+    server_ready_action: typing.Optional[typing.Union[ServerReadyAction, typing.Dict[builtins.str, typing.Any]]] = None,
+    skip_files: typing.Optional[typing.Sequence[builtins.str]] = None,
+    stop_on_entry: typing.Optional[builtins.bool] = None,
+    url: typing.Optional[builtins.str] = None,
+    web_root: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e672107e647965d3df7010fe525812b0c15f85ddada55b01f48ebe2c3d565725(
+    vscode: VsCode,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ee54c74ab4b20a8248223537312409aad3f546c2c5aeca6044e4346ce5a952d8(
+    *extensions: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d1a69619f76a087ea88b4c83f8cee17e5d30db36f27b14f84da086de6e449d0c(
+    *extensions: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__513f68cf91869cc8da990fa2a1bc57a9c643d25b8264e1c057f76e3decc6dea1(
+    vscode: VsCode,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__369e06bc45a74498b4cfed5bf740550cd9a57917b148178ef260593cb40c2a59(
+    setting: builtins.str,
+    value: typing.Any,
+    language: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__fa3e27ee6b180fccd6eab5d9670c7024eb3f8067cb08859636119e69f07de239(
+    settings: typing.Mapping[builtins.str, typing.Any],
+    languages: typing.Optional[typing.Union[builtins.str, typing.Sequence[builtins.str]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
